@@ -5,7 +5,7 @@ davies <- function(q,lambda,h = rep(1,length(lambda)),delta = rep(0,length(lambd
   if (length(delta) != r) stop("lambda and delta should have the same length!")
   
   out <- .C("qfc",lambdas=as.double(lambda),noncentral=as.double(delta),df=as.integer(h),r=as.integer(r),sigma=as.double(sigma),q=as.double(q),lim=as.integer(lim),
-             acc=as.double(acc),trace=as.double(rep(0,7)),ifault=as.integer(0),res=as.double(0), package='gaston')
+             acc=as.double(acc),trace=as.double(rep(0,7)),ifault=as.integer(0),res=as.double(0), PACKAGE = "gaston")
   
   if (out$ifault==1) warning('In Davies method : Requested accuracy could not be obtained.')
   if (out$ifault==2) warning('In Davies method : Round-off error possibly significant.')
