@@ -1,6 +1,8 @@
 // [[Rcpp::depends(RcppEigen)]]
 #include <RcppEigen.h>
 #include <iostream>
+#ifndef GASTONAIREMLn
+#define GASTONAIREMLn
 //#define ANY(_X_) (std::any_of(_X_.begin(), _X_.end(), [](bool x) {return x;})) 
 
 using namespace Rcpp;
@@ -245,3 +247,5 @@ void AIREMLn(const Eigen::MatrixBase<T1> & y, const Eigen::MatrixBase<T4> & x, c
 
   
 }
+#endif
+
